@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # Filename: humidity.py
 
-from numpy import log10,exp
+from math import log10,exp
 
 # Description:
 # conversions between different humidity quantities
@@ -66,7 +66,7 @@ def wvap2sh(e,p):
 
 def rh2ah(RH,p,T):
     '''conversion relative humidity to absolute humidity (kg Water per m^3 Air)'''
-        mixr=rh2mixr(RH, p,T)
-        sh=mixr2sh(mixr)
-        return  sh*rhov(T,p,sh) 
+    mixr=rh2mixr(RH, p,T)
+    sh=mixr2sh(mixr)
+    return  sh*rhov(T,p,sh) 
 
